import { scaffolderPlugin, createScaffolderFieldExtension } from '@backstage/plugin-scaffolder';
import React, { useState } from 'react';
import FormControl from '@material-ui/core/FormControl';
import { KubernetesValidatorFunctions } from '@backstage/catalog-model';
import { useApi, discoveryApiRef, fetchApiRef } from '@backstage/core-plugin-api';
import { ErrorPanel, Progress, Select } from '@backstage/core-components';
import { useAsync } from 'react-use';
import { get } from 'lodash';

const SelectFieldFromApi = (props) => {
  var _a;
  const discoveryApi = useApi(discoveryApiRef);
  const fetchApi = useApi(fetchApiRef);
  const [dropDownData, setDropDownData] = useState();
  const { error } = useAsync(async () => {
    const baseUrl = await discoveryApi.getBaseUrl("");
    const params = new URLSearchParams(props.uiSchema["ui:params"]);
    const response = await fetchApi.fetch(`${baseUrl}${props.uiSchema["ui:path"]}?${params}`);
    const body = await response.json();
    const array = get(body, props.uiSchema["ui:arraySelector"]);
    setDropDownData(array.map((item) => {
      let value;
      let label;
      if (props.uiSchema["ui:valueSelector"]) {
        value = get(item, props.uiSchema["ui:valueSelector"]);
        label = get(item, props.uiSchema["ui:labelSelector"]) || value;
      } else {
        if (!(typeof item === "string")) {
          throw new Error(`The item provided for the select drop down "${item}" is not a string`);
        }
        value = item;
        label = item;
      }
      if (!value) {
        throw new Error(`Failed to populate SelectFieldFromApi dropdown`);
      }
      return {
        value,
        label: label || value
      };
    }));
  });
  if (error) {
    return /* @__PURE__ */ React.createElement(ErrorPanel, {
      error
    });
  }
  if (!dropDownData) {
    return /* @__PURE__ */ React.createElement(Progress, null);
  }
  return /* @__PURE__ */ React.createElement(FormControl, {
    margin: "normal",
    required: props.required,
    error: ((_a = props.rawErrors) == null ? void 0 : _a.length) > 0 && !props.formData
  }, /* @__PURE__ */ React.createElement(Select, {
    items: dropDownData,
    label: "Select",
    onChange: props.onChange
  }));
};
const selectFieldFromApiValidation = (value, validation) => {
  if (!KubernetesValidatorFunctions.isValidObjectName(value)) {
    validation.addError("must start and end with an alphanumeric character, and contain only alphanumeric characters, hyphens, underscores, and periods. Maximum length is 63 characters.");
  }
};

const SelectFieldFromApiExtension = scaffolderPlugin.provide(createScaffolderFieldExtension({
  name: "SelectFieldFromApi",
  component: SelectFieldFromApi,
  validation: selectFieldFromApiValidation
}));

export { SelectFieldFromApiExtension };
//# sourceMappingURL=index.esm.js.map
